#
# spec file for package libXtst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXtst
%define lname	libXtst6
Version:        1.2.5
Release:        1.1
Summary:        Xlib-based client API for the XTEST and RECORD extensions
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXtst
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXtst/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(recordproto) >= 1.13.99.1
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext) >= 1.0.99.4
BuildRequires:  pkgconfig(xextproto) >= 7.0.99.3
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xorg-macros) >= 1.12

%description
The XTEST extension is a minimal set of client and server extensions
required to completely test the X11 server with no user intervention.
This extension is not intended to support general journaling and
playback of user actions.

The RECORD extension supports the recording and reporting of all core
X protocol and arbitrary X extension protocol.

%package -n %lname
Summary:        Xlib-based client API for the XTEST and RECORD extensions
Group:          System/Libraries
# Make electron apps happy
Provides:       libXtst = %{version}

%description -n %lname
The XTEST extension is a minimal set of client and server extensions
required to completely test the X11 server with no user intervention.
This extension is not intended to support general journaling and
playback of user actions.

The RECORD extension supports the recording and reporting of all core
X protocol and arbitrary X extension protocol.

%package devel
Summary:        Development files for the X11 XTEST and RECORD extensions
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The XTEST extension is a minimal set of client and server extensions
required to completely test the X11 server with no user intervention.
This extension is not intended to support general journaling and
playback of user actions.

The RECORD extension supports the recording and reporting of all core
X protocol and arbitrary X extension protocol.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXtst.so.6*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXtst.so
%_libdir/pkgconfig/xtst.pc
%_mandir/man3/*
%_docdir/%name

%changelog
* Fri Aug  2 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.5
  * This release fixes issues found by Coverity & gcc -fanalyzer
* Tue Sep 27 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.4
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * send_axes: Mark switch statement fallthrough as intentional
  * Resolve -Wsign-compare warnings
  * Variable scope reductions as suggested by cppcheck
  * Remove obsolete casts from Xmalloc() and Xcalloc() calls
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Mon Aug 10 2020 Ismail Dönmez <idonmez@suse.com>
- Add a Provides: libXtst = %%{version} to the library subpackage
  to make pre-packaged electron apps happy.
* Wed Nov  2 2016 sndirsch@suse.com
- tagged baselibs.conf as source in specfile
* Sat Oct 29 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.2.3:
  + Remove fallback for _XEatDataWords, require libX11 1.6 for it
  + Out of boundary access and endless loop in libXtst
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.2.2:
  This release provides the fix for the recently announced security issue
  CVE-2013-2063, along with a number of fixes to the build configuration.
- Packaging changes:
  + Remove Patch0: u_libXtst_Added-missing-xi-requires-to-pkconfig-file.patch
    Superseded by another upstreamed version
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
- Avoid calling fdupes outside of /usr
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.2.1:
  + Fix for gcc warning
  + Improvements to documentation
  + Build configuration improvements
* Fri Feb 24 2012 sndirsch@suse.com
- Added missing "xi" requires to pkconfig file (bnc#748808)
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
